@@ -1,6 +1,6 @@
 # ABSTRACT: A simple interface to ArangoDB REST API
 package Arango::Tango;
-$Arango::Tango::VERSION = '0.014';
+$Arango::Tango::VERSION = '0.015';
 use base 'Arango::Tango::API';
 use Arango::Tango::Database;
 use Arango::Tango::Collection;
@@ -12,6 +12,7 @@ use JSON;
 use MIME::Base64 3.11 'encode_base64url';
 use URI::Encode qw(uri_encode);
 
+
 BEGIN {
 Arango::Tango::API::_install_methods "Arango::Tango" => {
     engine                  => { rest => [ get => '_api/engine' ] },
@@ -127,6 +128,8 @@ Arango::Tango::API::_install_methods "Arango::Tango" => {
 
 }
 
+
+
 sub new {
     my ($package, %opts) = @_;
     my $self = bless { %opts } => $package;
@@ -134,6 +137,8 @@ sub new {
     $self->{host} ||= $ENV{ARANGO_DB_HOST} || "localhost";
     $self->{port} ||= $ENV{ARANGO_DB_PORT} || 8529;
 
+    $self->{scheme} ||= $ENV{ARANGO_DB_SCHEME} || 'http';
+
     $self->{username} ||= $ENV{ARANGO_DB_USERNAME} || "root";
     $self->{password} ||= $ENV{ARANGO_DB_PASSWORD} || "";
 
@@ -147,6 +152,8 @@ sub new {
 }
 
 
+
+
 sub _auth {
     my $self = shift;
     return "Basic " . encode_base64url( $self->{username} . ":" . $self->{password} );
@@ -168,7 +175,10 @@ sub list_databases {
 }
 
 
-
+sub http_status {
+    my $self = shift;
+    return exists($self->{last_error}) ? $self->{last_error} : 0;
+}
 
 1;
 
@@ -184,7 +194,7 @@ Arango::Tango - A simple interface to ArangoDB REST API
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSYS
 
@@ -260,10 +270,24 @@ Username to be used to connect to ArangoDB. Defaults to C<root>.
 
 Password to be used to connect to ArangoDB. Default to the empty string.
 
+=item C<scheme>
+
+HTTP scheme to use. Defaults to C<http>.
+
 =back
 
 =back
 
+=head2 Error Checking
+
+=over 4
+
+=item C<http_status>
+
+Returns the last HTTP status code.
+
+=back
+
 =head2 Database Manipulation
 
 =over 4
