@@ -1,6 +1,6 @@
 # ABSTRACT: ArangoDB Collection object
 package Arango::Tango::Collection;
-$Arango::Tango::Collection::VERSION = '0.014';
+$Arango::Tango::Collection::VERSION = '0.015';
 use warnings;
 use strict;
 
@@ -9,6 +9,7 @@ use Arango::Tango::API;
 BEGIN {
     Arango::Tango::API::_install_methods "Arango::Tango::Collection" => {
 
+        ## Document Management -- Keeping here for now.
         document => {
             rest => [ get => '{{database}}_api/document/{name}/{key}' ],
             inject_properties => [ 'database', 'name' ],
@@ -16,6 +17,15 @@ BEGIN {
             ## FIXME - Header parameters still not supported
            },
 
+        replace => {
+            rest => [ put => '{{database}}_api/document/{name}/{key}' ],
+            inject_properties => [ 'database', 'name' ],
+            signature => ['key'],
+            require_document => 1,
+           },
+
+        ## Collection Management
+
         load => {
             rest   => [ put => '{{database}}_api/collection/{name}/load'],
             schema => { count => { type => 'integer' }},
@@ -69,7 +79,6 @@ BEGIN {
             inject_properties => [ 'database', 'name' ],
         },
 
-
         figures => {
             rest => [ get => '{{database}}_api/collection/{name}/figures' ],
             schema => { withRevisions => { type => 'boolean' }, withData => {type=>'boolean' }},
@@ -146,7 +155,7 @@ Arango::Tango::Collection - ArangoDB Collection object
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 USAGE
 
